@@ -75,7 +75,7 @@ from types import GeneratorType, ModuleType
 from collections import deque
 from binascii import a2b_hex, b2a_hex
 
-VERSION = '0.04'
+VERSION = '0.05'
 
 PYTHON3 = sys.version_info >= (3, 0)
 if PYTHON3:
@@ -576,7 +576,7 @@ class Connection:
         ## attribute access protected by GIL
         sock = self._sock
         if sock is None:
-            raise IOError("Connection closed")
+            raise EOFError
         
         recv_buf = self._recv_buf
         recv_hmac = self._recv_hmac
@@ -591,6 +591,9 @@ class Connection:
                 select.select([sock], [], [], None)
                 continue
 
+            if not data:
+                raise EOFError
+
             recv_hmac.update(data)
             recv_buf.write(data)
             newlen = self._recv_expect - len(data)
@@ -691,8 +694,8 @@ class _GlobalProxy:
 class Client(Connection):
     '''Represents the client side of the connection. '''
 
-    _sendiv = 'CLNT'
-    _recviv = 'SRVR'
+    _sendiv = b'CLNT'
+    _recviv = b'SRVR'
     
     def __init__(self, key, sock_or_host=None, port=DEFAULT_PORT,
                  definitions='easycluster_code'):
@@ -1180,6 +1183,8 @@ class AutoThreadingClient(Client, threading.Thread):
             if e.errno != errno.ECONNRESET:
                 raise
         except EOFError:
+            ## Swallow this error so it isn't printed. Since we call close(),
+            ## any outstanding or future requests will fail.
             pass
         finally:
             self.close(*closeargs)
@@ -1288,8 +1293,8 @@ class ServerThread(threading.Thread):
 class Server(Connection):
     '''Represents the server side of a remote connection.'''
 
-    _sendiv = 'SRVR'
-    _recviv = 'CLNT'
+    _sendiv = b'SRVR'
+    _recviv = b'CLNT'
 
     def __init__(self, key, sock, peername):
         Connection.__init__(self, key)
@@ -1394,7 +1399,7 @@ class Server(Connection):
                     rtime = next_keep_alive - ctime
                     if rtime <= 0:
                         next_keep_alive = ctime + self._keep_alive_interval
-                        self.send_message(KEEPALIVE, '')
+                        self.send_message(KEEPALIVE, b'')
                         continue
                     r, w, e = select.select([self._sock], (), (), rtime)
                     if self._sock in r:
