@@ -347,7 +347,7 @@ def test_disconnect_thread(h, amt):
     print('Calling dosleep')
     try:
         h.dosleep(amt)
-    except IOError, e:
+    except IOError as e:
         print('Disconnection caused error: %s' % e)
     else:
         assert False, 'Exception not raised on close'
@@ -355,7 +355,7 @@ def test_disconnect_thread(h, amt):
 
 @define_test('Test disconnection')
 def disconnect_thread():
-    t1 = threading.Thread(target=test_disconnect_thread, args=(l2, 10))
+    t1 = threading.Thread(target=test_disconnect_thread, args=(l2, 2))
     t1.start()
     time.sleep(0.1)
     l2.close()
